pub struct RFSumcheck<C, R>(/* private fields */);Implementations
Sourceimpl<C, R> RFSumcheck<C, R>where
C: BaseFieldConfig + ProjectPrimitiveIntegersWithConfig,
C::Integer: ConstTranscribable,
R: SetElement + ProjectableToField<C>,
impl<C, R> RFSumcheck<C, R>where
C: BaseFieldConfig + ProjectPrimitiveIntegersWithConfig,
C::Integer: ConstTranscribable,
R: SetElement + ProjectableToField<C>,
Sourcepub fn prove_as_subprotocol(
transcript: &mut impl Transcript,
mles: Vec<DenseMultilinearExtension<R>>,
mles_f: Vec<DenseMultilinearExtension<C::Element>>,
nvars: usize,
degree: usize,
comb_fn: impl Fn(&C::Element, &[C::Element]) -> C::Element + Send + Sync,
field_cfg: &C,
) -> (RFSumcheckProof<C::Element, R>, RFProverState<C, R>)
pub fn prove_as_subprotocol( transcript: &mut impl Transcript, mles: Vec<DenseMultilinearExtension<R>>, mles_f: Vec<DenseMultilinearExtension<C::Element>>, nvars: usize, degree: usize, comb_fn: impl Fn(&C::Element, &[C::Element]) -> C::Element + Send + Sync, field_cfg: &C, ) -> (RFSumcheckProof<C::Element, R>, RFProverState<C, R>)
Random field sumcheck prover. Samples a random field element, projects the input MLEs and performs the sumcheck proving algorithm.
Arguments
transcript: A mutable reference to a Fiat-ShamirTranscript.mles: AVecof dense multilinear extension over the input semiringR. These will be projected by the prover.mles_f: AVecof dense multilinear extension over the random field. E.g.eq_rcan go into this argument. These will not be projected by the prover.nvars: The number of variables over which themlesare defined. This must be consistent across allmles.degree: The maximum combined degree of themlesunder thecomb_fn.comb_fn: A closure that defines the combination function $G(\alpha, \text{mles}(x))$. It takes the projecting element $\alpha$ the prover has sampled and a slice of field elements (the evaluations of themlesat a point $x$) and returns a single field element. The element $\alpha$ might be used to project some parts of the sumcheck polynomial, e.g. if a constraint systems requires projecting too.config: The configuration for the underlying field used in the protocol. The protocol does not sample the random prime and assumes it comes in this argument.
Sourcepub fn verify_as_subprotocol(
transcript: &mut impl Transcript,
num_vars: usize,
degree: usize,
proof: &RFSumcheckProof<C::Element, R>,
field_cfg: C,
) -> Result<Subclaim<C::Element>, RFSumcheckError<C::Element>>
pub fn verify_as_subprotocol( transcript: &mut impl Transcript, num_vars: usize, degree: usize, proof: &RFSumcheckProof<C::Element, R>, field_cfg: C, ) -> Result<Subclaim<C::Element>, RFSumcheckError<C::Element>>
The verifier part of the random field sumcheck protocol.
Arguments
transcript: A mutable reference to a Fiat-ShamirTranscript.num_vars: The number of variables over which the sum was originally computed.degree: The maximum combined degree of the underlying polynomial $G(x)$. This must match the degree used by the Prover.claimed_sum: The initial claimed value of the sum.proof: A reference to theSumcheckProof<F>generated by the Prover.config: The configuration for the underlying field used in the protocol.